CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
139 lines
4.7 KiB
C++
139 lines
4.7 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#include <hip/hip_runtime_api.h>
|
|
#include <hip/hip_gl_interop.h>
|
|
|
|
#include "gl_interop_common.hh"
|
|
|
|
HIP_TEST_CASE(Unit_hipGraphicsSubResourceGetMappedArray_Positive_Basic) {
|
|
CHECK_IMAGE_SUPPORT
|
|
|
|
GLContextScopeGuard gl_context;
|
|
|
|
const int device_count = HipTest::getDeviceCount();
|
|
unsigned int gl_device_count = 0;
|
|
std::vector<int> gl_devices(device_count, -1);
|
|
|
|
// Initialize GL interop
|
|
HIP_CHECK(hipGLGetDevices(&gl_device_count, gl_devices.data(), device_count, hipGLDeviceListAll));
|
|
REQUIRE(gl_device_count == 1);
|
|
REQUIRE(gl_devices.at(0) == 0);
|
|
|
|
GLImageObject tex;
|
|
|
|
hipGraphicsResource* tex_resource;
|
|
|
|
HIP_CHECK(
|
|
hipGraphicsGLRegisterImage(&tex_resource, tex, GL_TEXTURE_2D, hipGraphicsRegisterFlagsNone));
|
|
|
|
HIP_CHECK(hipGraphicsMapResources(1, &tex_resource, 0));
|
|
|
|
hipArray_t image_devptr = nullptr;
|
|
HIP_CHECK(hipGraphicsSubResourceGetMappedArray(&image_devptr, tex_resource, 0, 0));
|
|
|
|
REQUIRE(image_devptr != nullptr);
|
|
|
|
HIP_CHECK(hipGraphicsUnmapResources(1, &tex_resource, 0));
|
|
|
|
HIP_CHECK(hipGraphicsUnregisterResource(tex_resource));
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipGraphicsSubResourceGetMappedArray_Negative_Parameters) {
|
|
CHECK_IMAGE_SUPPORT
|
|
|
|
GLContextScopeGuard gl_context;
|
|
|
|
const int device_count = HipTest::getDeviceCount();
|
|
unsigned int gl_device_count = 0;
|
|
std::vector<int> gl_devices(device_count, -1);
|
|
|
|
// Initialize GL interop
|
|
HIP_CHECK(hipGLGetDevices(&gl_device_count, gl_devices.data(), device_count, hipGLDeviceListAll));
|
|
REQUIRE(gl_device_count == 1);
|
|
REQUIRE(gl_devices.at(0) == 0);
|
|
|
|
GLImageObject tex;
|
|
|
|
hipGraphicsResource* tex_resource;
|
|
|
|
HIP_CHECK(
|
|
hipGraphicsGLRegisterImage(&tex_resource, tex, GL_TEXTURE_2D, hipGraphicsRegisterFlagsNone));
|
|
|
|
HIP_CHECK(hipGraphicsMapResources(1, &tex_resource, 0));
|
|
|
|
hipArray_t image_devptr = nullptr;
|
|
|
|
SECTION("array == nullptr") {
|
|
HIP_CHECK_ERROR(hipGraphicsSubResourceGetMappedArray(nullptr, tex_resource, 0, 0), hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("non-texture resource") {
|
|
GLBufferObject vbo;
|
|
hipGraphicsResource* vbo_resource;
|
|
|
|
HIP_CHECK(hipGraphicsGLRegisterBuffer(&vbo_resource, vbo, hipGraphicsRegisterFlagsNone));
|
|
HIP_CHECK(hipGraphicsMapResources(1, &vbo_resource, 0));
|
|
|
|
HIP_CHECK_ERROR(hipGraphicsSubResourceGetMappedArray(&image_devptr, vbo_resource, 0, 0),
|
|
hipErrorNotMappedAsArray);
|
|
|
|
HIP_CHECK(hipGraphicsUnmapResources(1, &vbo_resource, 0));
|
|
HIP_CHECK(hipGraphicsUnregisterResource(vbo_resource));
|
|
}
|
|
|
|
SECTION("unregistered resource") {
|
|
hipGraphicsResource* unregistered_resource;
|
|
HIP_CHECK(hipGraphicsGLRegisterImage(&unregistered_resource, tex, GL_TEXTURE_2D,
|
|
hipGraphicsRegisterFlagsNone));
|
|
HIP_CHECK(hipGraphicsUnregisterResource(unregistered_resource));
|
|
HIP_CHECK_ERROR(
|
|
hipGraphicsSubResourceGetMappedArray(&image_devptr, unregistered_resource, 0, 0),
|
|
hipErrorInvalidHandle);
|
|
}
|
|
|
|
SECTION("not mapped resource") {
|
|
hipGraphicsResource* not_mapped_resource;
|
|
HIP_CHECK(hipGraphicsGLRegisterImage(¬_mapped_resource, tex, GL_TEXTURE_2D,
|
|
hipGraphicsRegisterFlagsNone));
|
|
HIP_CHECK_ERROR(hipGraphicsSubResourceGetMappedArray(&image_devptr, not_mapped_resource, 0, 0),
|
|
hipErrorNotMapped);
|
|
HIP_CHECK(hipGraphicsUnregisterResource(not_mapped_resource));
|
|
}
|
|
|
|
SECTION("unmapped resource") {
|
|
hipGraphicsResource* unmapped_resource;
|
|
|
|
HIP_CHECK(hipGraphicsGLRegisterImage(&unmapped_resource, tex, GL_TEXTURE_2D,
|
|
hipGraphicsRegisterFlagsNone));
|
|
|
|
HIP_CHECK(hipGraphicsMapResources(1, &unmapped_resource, 0));
|
|
HIP_CHECK(hipGraphicsUnmapResources(1, &unmapped_resource, 0));
|
|
|
|
HIP_CHECK_ERROR(hipGraphicsSubResourceGetMappedArray(&image_devptr, unmapped_resource, 0, 0),
|
|
hipErrorNotMapped);
|
|
|
|
HIP_CHECK(hipGraphicsUnregisterResource(unmapped_resource));
|
|
}
|
|
|
|
SECTION("invalid arrayIndex") {
|
|
HIP_CHECK_ERROR(hipGraphicsSubResourceGetMappedArray(&image_devptr, tex_resource,
|
|
std::numeric_limits<int>::max(), 0),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("invalid mipLevel") {
|
|
HIP_CHECK_ERROR(hipGraphicsSubResourceGetMappedArray(&image_devptr, tex_resource, 0,
|
|
std::numeric_limits<int>::max()),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
HIP_CHECK(hipGraphicsUnmapResources(1, &tex_resource, 0));
|
|
|
|
HIP_CHECK(hipGraphicsUnregisterResource(tex_resource));
|
|
}
|